@@ -52,6 +52,7 @@ with contextlib.suppress(ImportError):
 from . import matchers
 from . import masks
 from . import classes
+from .compat.py38 import removesuffix
 
 
 __all__ = ['Path', 'TempDir']
@@ -142,7 +143,10 @@ class Path(str):
     .. seealso:: :mod:`os.path`
     """
 
-    def __init__(self, other=''):
+    def __new__(cls, other='.'):
+        return super().__new__(cls, other)
+
+    def __init__(self, other='.'):
         if other is None:
             raise TypeError("Invalid initial value for path: None")
         with contextlib.suppress(AttributeError):
@@ -274,11 +278,28 @@ class Path(str):
         base, ext = self.module.splitext(self.name)
         return base
 
+    def with_stem(self, stem):
+        """Return a new path with the stem changed.
+
+        >>> Path('/home/guido/python.tar.gz').with_stem("foo")
+        Path('/home/guido/foo.gz')
+        """
+        return self.with_name(stem + self.suffix)
+
+    @property
+    def suffix(self):
+        """The file extension, for example ``'.py'``."""
+        f, suffix = self.module.splitext(self)
+        return suffix
+
     @property
     def ext(self):
-        """The file extension, for example ``'.py'``."""
-        f, ext = self.module.splitext(self)
-        return ext
+        warnings.warn(
+            ".ext is deprecated; use suffix",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.suffix
 
     def with_suffix(self, suffix):
         """Return a new path with the file suffix changed (or added, if none)
@@ -335,6 +356,14 @@ class Path(str):
         """,
     )
 
+    def with_name(self, name):
+        """Return a new path with the name changed.
+
+        >>> Path('/home/guido/python.tar.gz').with_name("foo.zip")
+        Path('/home/guido/foo.zip')
+        """
+        return self._next_class(removesuffix(self, self.name) + name)
+
     def splitpath(self):
         """Return two-tuple of ``.parent``, ``.name``.
 
@@ -472,8 +501,8 @@ class Path(str):
 
     # --- Listing, searching, walking, and matching
 
-    def listdir(self, match=None):
-        """List of items in this directory.
+    def iterdir(self, match=None):
+        """Yields items in this directory.
 
         Use :meth:`files` or :meth:`dirs` instead if you want a listing
         of just files or just subdirectories.
@@ -486,7 +515,15 @@ class Path(str):
         .. seealso:: :meth:`files`, :meth:`dirs`
         """
         match = matchers.load(match)
-        return list(filter(match, (self / child for child in os.listdir(self))))
+        return filter(match, (self / child for child in os.listdir(self)))
+
+    def listdir(self, match=None):
+        warnings.warn(
+            ".listdir is deprecated; use iterdir",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return list(self.iterdir(match=match))
 
     def dirs(self, *args, **kwargs):
         """List of this directory's subdirectories.
@@ -495,9 +532,9 @@ class Path(str):
         This does not walk recursively into subdirectories
         (but see :meth:`walkdirs`).
 
-        Accepts parameters to :meth:`listdir`.
+        Accepts parameters to :meth:`iterdir`.
         """
-        return [p for p in self.listdir(*args, **kwargs) if p.isdir()]
+        return [p for p in self.iterdir(*args, **kwargs) if p.isdir()]
 
     def files(self, *args, **kwargs):
         """List of the files in self.
@@ -505,10 +542,10 @@ class Path(str):
         The elements of the list are Path objects.
         This does not walk into subdirectories (see :meth:`walkfiles`).
 
-        Accepts parameters to :meth:`listdir`.
+        Accepts parameters to :meth:`iterdir`.
         """
 
-        return [p for p in self.listdir(*args, **kwargs) if p.isfile()]
+        return [p for p in self.iterdir(*args, **kwargs) if p.isfile()]
 
     def walk(self, match=None, errors='strict'):
         """Iterator over files and subdirs, recursively.
@@ -531,7 +568,7 @@ class Path(str):
         match = matchers.load(match)
 
         try:
-            childList = self.listdir()
+            childList = self.iterdir()
         except Exception as exc:
             errors(f"Unable to list directory '{self}': {exc}")
             return
@@ -1333,7 +1370,7 @@ class Path(str):
         dst = self._next_class(dst)
         dst.makedirs_p()
 
-        sources = self.listdir()
+        sources = list(self.iterdir())
         _ignored = ignore(self, [item.name for item in sources])
 
         def ignored(item):
@@ -1425,30 +1462,22 @@ class Path(str):
             errors=errors,
             newline=newline,
         )
-        try:
-            perm = os.fstat(readable.fileno()).st_mode
-        except OSError:
-            writable = self.open(
-                'w' + mode.replace('r', ''),
-                buffering=buffering,
-                encoding=encoding,
-                errors=errors,
-                newline=newline,
-            )
-        else:
-            os_mode = os.O_CREAT | os.O_WRONLY | os.O_TRUNC
-            os_mode |= getattr(os, 'O_BINARY', 0)
-            fd = os.open(self, os_mode, perm)
-            writable = open(
-                fd,
-                "w" + mode.replace('r', ''),
-                buffering=buffering,
-                encoding=encoding,
-                errors=errors,
-                newline=newline,
-            )
-            with contextlib.suppress(OSError, AttributeError):
-                self.chmod(perm)
+
+        perm = os.stat(readable.fileno()).st_mode
+        os_mode = os.O_CREAT | os.O_WRONLY | os.O_TRUNC
+        os_mode |= getattr(os, 'O_BINARY', 0)
+        fd = os.open(self, os_mode, perm)
+        writable = open(
+            fd,
+            "w" + mode.replace('r', ''),
+            buffering=buffering,
+            encoding=encoding,
+            errors=errors,
+            newline=newline,
+        )
+        with contextlib.suppress(OSError, AttributeError):
+            self.chmod(perm)
+
         try:
             yield readable, writable
         except Exception:
